<?php
/**
 * The function php file contain all theme-based customisation and functions
 *
 * @package    stockist
 */

define( 'PRODUCTIVE_STOCKIST_THEME_BASE_PATH', get_theme_file_path() );
define( 'PRODUCTIVE_STOCKIST_THEME_BASE_URI', get_theme_file_uri() );

$stockist_theme_version_obj = wp_get_theme();
$stockist_theme_version = $stockist_theme_version_obj->get( 'Version' );

/**
 * Method stockist_scripts
 */
function stockist_scripts() {

    global $stockist_theme_version;
        
        wp_enqueue_style('stockist_googlefonts', wptt_get_webfont_url( 'https://fonts.googleapis.com/css2?family=Poppins:ital,wght@0,300;0,400;0,500;0,600;0,700;0,800;0,900;1,400&display=swap' ), array(), $stockist_theme_version );

	wp_enqueue_style( 'stockist-child-style', get_stylesheet_uri(), array(), $stockist_theme_version );
	
	if ( ! is_admin() && is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
	    wp_enqueue_script( 'comment-reply' );
	}
        	
        wp_enqueue_script( 'stockist-child-js', PRODUCTIVE_STOCKIST_THEME_BASE_URI . '/assets/js/child-theme.js', array(), $stockist_theme_version, true );

}
// set priority at 100 to allow parent scripts enqueue first.
add_action( 'wp_enqueue_scripts', 'stockist_scripts', 100 );


/**
 * Load (wp_enqueue_script) admin css * JS files.
 */
function stockist_admin_scripts() {
    
    global $stockist_theme_version;
    
    $admin_ajax_php_class = array(
        'ajax_admin_url' => admin_url( 'admin-ajax.php' ),
    );
    
    wp_enqueue_style( 'stockist_admin_css', PRODUCTIVE_STOCKIST_THEME_BASE_URI . '/assets/admin/css/admin-style.css', array(), $stockist_theme_version );
    wp_enqueue_script( 'stockist_admin_js_handle', PRODUCTIVE_STOCKIST_THEME_BASE_URI . '/assets/admin/js/admin-theme-ajax.js', array(), $stockist_theme_version, true );
    
    wp_localize_script(
        'stockist_admin_js_handle',
        'stockist_admin_js_url_name',
        $admin_ajax_php_class
        );
    
}
// hook for stockist_admin_scripts.
add_action( 'admin_enqueue_scripts', 'stockist_admin_scripts' );


/**
 * Method enable featured image.
 */
function stockist_setup_theme() {
    
    add_theme_support('post-thumbnails');
    add_theme_support('wp-block-styles');
    add_theme_support('responsive-embeds');
    add_theme_support('custom-logo');
    add_theme_support('align-wide');
    add_theme_support('title-tags');
    add_theme_support('automatic-feed-links');
    
    $args = array(
        'gallery',
        'caption',
        'script',
        'search-form',
        'comment-form',
        'comment-list',
        'navigation-widgets',
    );
    
    add_theme_support( 'html5', $args );
    
    // initiate text-domain.
    load_theme_textdomain( 'stockist', PRODUCTIVE_STOCKIST_THEME_BASE_PATH . '/languages' );
    
}
// hook for stockist_setup_theme.
add_action( 'after_setup_theme', 'stockist_setup_theme' );


/**
 * Register Extra sidebar widgets
 */
function stockist_widgets_home_highlights() {
    
    register_sidebar(
        array(
            'name' => esc_html__('Highlighted Homepage Products', 'stockist'),
            'id' => 'homepage_highlights_widget',
            'before_widget' => '<div class="productive_ecommerce_widget_container_home_highlights">',
            'after_widget' => '</div>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        )
        );
}
add_action( 'widgets_init', 'stockist_widgets_home_highlights' );


/**
 * Add hooks for the sidebar widgets.
 *
 * @param string $class css class name to use to wrap the sidebar.
 */
function stockist_get_home_highlights( $class = '' ) {
    if ( is_active_sidebar( 'homepage_highlights_widget' ) ) {
        if ( '' != $class ) {
            echo '<div class="' . esc_attr( $class ) . '">';
            if ( is_active_sidebar( 'homepage_highlights_widget' ) ) {
                dynamic_sidebar( 'homepage_highlights_widget' );
            }
            echo '</div>';
        } else {
            if ( is_active_sidebar( 'homepage_highlights_widget' ) ) {
                dynamic_sidebar( 'homepage_highlights_widget' );
            }
        }
    }
}
add_action( 'display_stockist_get_home_highlights', 'stockist_get_home_highlights' );


require PRODUCTIVE_STOCKIST_THEME_BASE_PATH . '/includes/woocommerce.php';


