<?php
/**
 * Header page.
 *
 * @package stockist
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php echo bloginfo( 'charset' ); ?>">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
    
<?php wp_body_open(); ?>
<?php productive_ecommerce_body_open(); ?>
<?php

    $is_wc_activated = productive_ecommerce_is_woocommerce_activated();

    $customiser_show_search_icon = productive_ecommerce_enable_header_search();
    $customiser_show_account_icon = productive_ecommerce_enable_header_account() && $is_wc_activated;
    $customiser_show_cart_icon = productive_ecommerce_enable_header_cart() && $is_wc_activated;
    
    $site_container_no_logo = '';
    if ( !has_custom_logo() ) {
        $site_container_no_logo = 'site-container-no-logo';
    }
?>
<header class="site-header">
        
        <div class="site-container header-searchbox-container">
            <div class="header-searchbox-wrapper">
                <?php if ( $customiser_show_search_icon ) { ?>
                    <div class="">
                        <?php
                            get_search_form(
                                array( 
                                    'arial_label' => __( 'Search...', 'stockist' ), 
                                )
                            );
                        ?>
                    </div>
                <?php } ?>
            </div>
            <button class="container-close-button right">
                <i class="material-symbols-outlined">close</i>
                <span class="screen-reader-text"><?php esc_html_e('Close Banner', 'stockist'); ?></span>
            </button>
        </div>

        <?php if ( is_active_sidebar( 'header_callout' ) ) { ?>
            <div class="site-container header-callout">
                <?php do_action( 'display_header_callout', 'site-header-callout ' ); ?>
                <button class="container-close-button right">
                    <i class="material-symbols-outlined">close</i>
                    <span class="screen-reader-text"><?php esc_html_e('Close Banner', 'stockist'); ?></span>
                </button>
            </div>
        <?php } ?>
 
        <div class="minicart-display-container"></div>

        <div class="site-container header-minibar">
            <div class="site-header-minibar">
                <div class="flex-content-container">
                    <div class="flex-content-60">
                        <div class="social-phone-email-container">
                            <?php do_action( 'display_productive_ecommerce_social_email_and_phone' ); ?>
                        </div>
                    </div>
                    <div class="flex-content-40">
                        <div class="social-media-container">
                            <?php do_action( 'display_productive_ecommerce_social_media_block' ); ?>
                        </div>
                    </div>
                </div>
            </div>
            <div class="clear_min"></div>
        </div>

        <div class="site-container <?php echo esc_attr( $site_container_no_logo );?>">

                 <div class="site-header-logo">

                         <div class="float_left">
                                <?php if ( !has_custom_logo() ) { ?>
                                <div class="site-header-logo-text-name">
                                        <a class="logo" href="<?php echo esc_url( home_url() ); ?>" >
                                           <?php bloginfo( 'name' ); ?>
                                        </a>
                                </div>
                                <div class="site-header-logo-text-desc">
                                        <a class="logo" href="<?php echo esc_url( home_url() ); ?>" >
                                           <?php bloginfo( 'description' ); ?>
                                        </a>
                                </div>
                                <?php } else { ?>

                                        <?php the_custom_logo(); ?>

                                <?php } ?>
                        </div>

                        <div class="float_right"> 

                        <span class="show_in_small_screen_only header-mini-items-mobile">
                            
                            <button class="site-header-search-icon child_theme bigscreen-only inline-blocked">
                                <i class="add_search material-symbols-outlined">search</i>
                                <i class="add_highlight_off material-symbols-outlined">highlight_off</i>
                                <span class="screen-reader-text"><?php esc_html_e('Menu', 'stockist'); ?></span>
                            </button>

                            <?php if ( $customiser_show_account_icon ) { ?>
                               <a title="<?php esc_attr_e( 'Account', 'stockist'); ?>" class="righted ten_right_padding" href="<?php echo esc_url( home_url() ); ?>/my-account">
                                   <i class="material-icons-round mini-item">account_circle</i> 
                               </a>
                        <?php } ?>
                        <?php if ( $customiser_show_cart_icon ) { ?>
                            <a title="<?php esc_attr_e( 'Shopping Basket', 'stockist'); ?>"  class="righted open-minicart-button-icon" href="<?php echo esc_url( wc_get_cart_url() ); ?>">
                               <i class="material-icons-round mini-item minicart">shopping_bag</i>
                               <span class="minibasket-count"><?php echo WC()->cart->get_cart_contents_count(); ?></span>
                            </a>
                        <?php } ?>
                        </span>
                            
                        <div class="clear_min"></div>
                        </div>

                        <div class="clear_min"></div>
                 </div>
                 <div class="site-header-main">
                         <div class="flex-content-container">
                             <div class="flex-content-100 righted bigscreen-only-blocked header-mini-items">
                                 
                                <button class="site-header-search-icon child_theme bigscreen-only inline-blocked">
                                    <i class="add_search material-symbols-outlined">search</i>
                                    <i class="add_highlight_off material-symbols-outlined">highlight_off</i>
                                    <span class="screen-reader-text"><?php esc_html_e('Menu', 'stockist'); ?></span>
                                </button>
                                 
                                <?php if ( $customiser_show_account_icon ) { ?>
                                        <a title="<?php esc_attr_e( 'Account', 'stockist'); ?>" class="righted ten_right_padding" href="<?php echo esc_url( home_url() ); ?>/my-account">
                                            <i class="material-icons-round mini-item">account_circle</i> 
                                        </a>
                                <?php } ?>
                                <?php if ( $customiser_show_cart_icon ) { ?>
                                     <a title="<?php esc_attr_e( 'Shopping Basket', 'stockist'); ?>"  class="righted open-minicart-button-icon" href="<?php echo esc_url( wc_get_cart_url() ); ?>">
                                        <i class="material-icons-round mini-item minicart">shopping_bag</i>
                                        <span class="minibasket-count"><?php echo WC()->cart->get_cart_contents_count(); ?></span>
                                     </a>
                                <?php } ?>
                                 
                            </div>
                         </div>
                        <div class="clear_min"></div>
                 </div>

                 <div class="clear_min"></div>

        </div>

        <div class="clear_min"></div>

        <div class="header-category-container">
            <div class="site-container">
                
                <div class="header-category-container-grid">
                    
                    <div class="header-category-menu">
                        <div class="header-category-menu-title">
                            <i class="material-symbols-outlined">filter_list</i>
                            <span><?php echo esc_html__('Top Categories', 'stockist') ?></span>
                            <button>
                                <i class="material-icons icon_menu">arrow_drop_down</i>
                                <i class="material-icons icon_close">arrow_drop_up</i>
                            </button>
                            <div class="header-category-menu-list noned">
                                <?php stockist_do_header_menu_categories(1); ?>
                            </div>
                        </div>
                        
                    </div>
                    
                    <div class="mid-header-center-container">
                        <div class="announcement-animated"><div id="animatemetext"></div></div>
                    </div>
                    
                    <div class="mid-header-right-container">
                        <div class="">
                            <button class="site-extra-header-menu-icon bigscreen-only-inline-blocked">
                                <i class="material-symbols-outlined main-menu icon_menu">menu</i>
                                <i class="material-symbols-outlined main-menu icon_close">close</i>
                                <span class="screen-reader-text"><?php esc_html_e('Menu', 'stockist'); ?></span>
                            </button>
                            
                            <!-- nav icon -->
                            <button class="site-header-menu-icon show_in_small_screen_only">
                                    <i class="material-symbols-outlined main-menu icon_menu">menu</i>
                                    <i class="material-symbols-outlined main-menu icon_close">close</i>
                                    <span class="screen-reader-text"><?php esc_html_e('Menu', 'stockist'); ?></span>
                            </button>

                         </div>

                    </div>
                    <div class="clear_min"></div>
                </div>
                
            </div>
        </div>

        <div class="clear_min"></div>

        <div class="header-main-header-nav-container site-header-nav site-header-nav-bigscreen noned">
            <div class="site-container">
                <div class="">
                    <?php do_action( 'display_productive_ecommerce_header_nav', 'site-header-nav site-header-nav-bigscreen' ); ?>
                </div>
            </div>
        </div>
        
        <div class="show_in_small_screen_only menu-nav">
               <?php do_action( 'display_productive_ecommerce_header_nav', 'site-header-nav site-header-nav-smallscreen' ); ?>
        </div>

       <div class="clear_min"></div>
       
</header>
	
