<?php
/**
 * The woocommerce php file contain all woocommerce-based customisation and functions
 *
 * @package stockist
 */


/**
 * Method stockist_is_woocommerce_activated
 *
 * @return boolean
 */
function stockist_is_woocommerce_activated() {
    return class_exists( 'woocommerce' );
}

/**
 * Method stockist_do_header_menu_categories
 */
function stockist_do_header_menu_categories( $children_depth = 0 ) {
    $args = array(
        'taxonomy' => 'product_cat',
        'hide_empty' => true,
        'parent' => 0
    );
    
    $categories = get_terms( $args );
    if ( !empty( $categories ) && !is_wp_error( $categories ) ) {
        
        foreach ( $categories as $category ) {
            echo '<div class="header-category-menu-item">';
                echo '<a href="' .  esc_url( get_term_link( $category ) ) . '">';
                $thumbnail_url = stockist_get_category_thumbnail_url($category->term_id);
                echo '<img src="' . esc_url( $thumbnail_url ) . '" alt="" width="40px" height="10px" />';
                echo '<span>' . $category->name . '</span>';
                echo '</a>';
            echo '</div>';
        }
        echo '<div class="clear_min"></div>';
    } else {
        echo '<div class="header-category-menu-item"><span>No Product Categories.</span></div>';
    }
}
add_action( 'display_woocommerce_before_shop_loop', 'stockist_woocommerce_before_shop_loop' );


function stockist_get_category_thumbnail_url( $parent_category_id, $thumbnail_type = 'thumbnail_id' ) {
    $thumbnail_id = get_term_meta($parent_category_id, $thumbnail_type, true );
    $url = wp_get_attachment_url($thumbnail_id);
    return $url;
}

